@@ -17,15 +17,12 @@ def monitor(app, body):
 def insert(app, body, project_id=0):
     if project_id == 0:
         jobs.insert_jobs_from_all_projects.s(app.settings).apply_async()
-        return {
-            "status": 202,
-            "title": "Accepted",
-        }, 202
-
-    data = ctrl.insert_jobs_from_project(app.settings, project_id)
-    if data:
-        return data, 200
-    return {}, 204
+    else:
+        jobs.insert_jobs_from_project.s(app.settings, project_id).apply_async()
+    return {
+        "status": 202,
+        "title": "Accepted",
+    }, 202
 
 
 @endpoint
